@@ -1,33 +1,32 @@
-# -*- coding: utf-8 -*-
+from AccessControl import getSecurityManager
 from plone.app.layout.globals.interfaces import IBodyClassAdapter
 from plone.app.layout.globals.interfaces import ILayoutPolicy
 from plone.app.layout.globals.interfaces import IViewView
-from plone.app.layout.icons.interfaces import IContentIcon
 from plone.i18n.normalizer.interfaces import IIDNormalizer
 from plone.memoize.view import memoize
 from plone.portlets.interfaces import IPortletManager
 from plone.portlets.interfaces import IPortletManagerRenderer
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone.interfaces.controlpanel import ILinkSchema
-from Products.CMFPlone.interfaces.controlpanel import ISiteSchema
+from plone.base.interfaces.controlpanel import ILinkSchema
+from plone.base.interfaces.controlpanel import ISiteSchema
 from Products.Five.browser.metaconfigure import ViewMixinForTemplates
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
-from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile as ZopeViewPageTemplateFile  # noqa
+from zope.browserpage.viewpagetemplatefile import (
+    ViewPageTemplateFile as ZopeViewPageTemplateFile,
+)
 from zope.component import adapter
 from zope.component import getAdapters
 from zope.component import getMultiAdapter
 from zope.component import getUtility
 from zope.component import queryMultiAdapter
 from zope.component import queryUtility
-from zope.deprecation import deprecate
 from zope.interface import alsoProvides
 from zope.interface import implementer
 from zope.interface import Interface
 from zope.publisher.browser import BrowserView
 
 import json
-import six
 
 
 TEMPLATE_CLASSES = (
@@ -39,8 +38,7 @@ TEMPLATE_CLASSES = (
 
 @implementer(ILayoutPolicy)
 class LayoutPolicy(BrowserView):
-    """A view that gives access to various layout related functions.
-    """
+    """A view that gives access to various layout related functions."""
 
     @property
     @memoize
@@ -57,8 +55,7 @@ class LayoutPolicy(BrowserView):
             alsoProvides(view, IViewView)
 
     def hide_columns(self, column_left, column_right):
-        """Returns a CSS class matching the current column status.
-        """
+        """Returns a CSS class matching the current column status."""
         if not column_right and not column_left:
             return "visualColumnHideOneTwo"
         if column_right and not column_left:
@@ -93,65 +90,30 @@ class LayoutPolicy(BrowserView):
 
         return renderer.visible
 
-    @memoize
-    def icons_visible(self):
-        """Returns True if icons should be shown or False otherwise.
-        """
-        context = self.context
-        membership = getToolByName(context, "portal_membership")
-        anon = membership.isAnonymousUser()
-
+    def _image_visibility(self, name):
+        """check if image {name} is visible with current settings and user"""
         registry = getUtility(IRegistry)
         settings = registry.forInterface(ISiteSchema, prefix="plone", check=False)
-        icon_visibility = settings.icon_visibility
-
-        if icon_visibility == "enabled":
+        visibility = getattr(settings, f"{name}_visibility")
+        if visibility == "enabled":
             return True
-        elif icon_visibility == "authenticated" and not anon:
-            return True
-        else:
+        if visibility != "authenticated":
             return False
+        user = getSecurityManager().getUser()
+        return user is not None and user.getUserName() != "Anonymous User"
+
+    @memoize
+    def icons_visible(self):
+        """Returns True if icons should be shown or False otherwise."""
+        return self._image_visibility("icon")
 
     @memoize
     def thumb_visible(self):
-        """Returns True if thumbs should be shown or False otherwise.
-        """
-        context = self.context
-        membership = getToolByName(context, "portal_membership")
-        anon = membership.isAnonymousUser()
-        registry = getUtility(IRegistry)
-        settings = registry.forInterface(ISiteSchema, prefix="plone", check=False)
-        thumb_visibility = settings.thumb_visibility
-
-        if thumb_visibility == "enabled":
-            return True
-        elif thumb_visibility == "authenticated" and not anon:
-            return True
-        else:
-            return False
-
-    @deprecate(
-        "deprecated since Plone 4, ContentIcons are rendered as Fonts now see"
-        "https://docs.plone.org/develop/addons/index.html"
-        "#upgrading-to-plone-5-1."
-    )
-    def getIcon(self, item):
-        """Returns an object which implements the IContentIcon interface and
-        provides the informations necessary to render an icon. The item
-        parameter needs to be adaptable to IContentIcon. Icons can be disabled
-        globally or just for anonymous users with the icon_visibility property
-        in site_properties.
-        """
-        context = self.context
-        if not self.icons_visible():
-            icon = getMultiAdapter((context, self.request, None), IContentIcon)
-        else:
-            icon = getMultiAdapter((context, self.request, item), IContentIcon)
-        return icon
+        """Returns True if thumbs should be shown or False otherwise."""
+        return self._image_visibility("thumb")
 
     def _toolbar_classes(self):
-        """current toolbar controlling classes
-        """
+        """current toolbar controlling classes"""
         if not self._context_state.is_toolbar_visible():
             return set()
 
@@ -237,7 +199,7 @@ class LayoutPolicy(BrowserView):
         - pat-markspeciallinks: mark special links is set
         """
         portal_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_portal_state"
+            (self.context, self.request), name="plone_portal_state"
         )
         normalizer = queryUtility(IIDNormalizer)
         registry = getUtility(IRegistry)
@@ -283,6 +245,13 @@ class LayoutPolicy(BrowserView):
         else:
             body_classes.add("thumbs-off")
 
+        # classes for column visibility: col-content, col-one, col-two:
+        body_classes.add("col-content")
+        if self.have_portlets("plone.leftcolumn", view):
+            body_classes.add("col-one")
+        if self.have_portlets("plone.rightcolumn", view):
+            body_classes.add("col-two")
+
         # permissions required. Useful to theme frontend and backend
         # differently
         permissions = []
@@ -320,7 +289,7 @@ class LayoutPolicy(BrowserView):
                 extra_classes = body_class_adapter.get_classes(template, view) or []
             except TypeError:  # This adapter is implemented without arguments
                 extra_classes = body_class_adapter.get_classes() or []
-            if isinstance(extra_classes, six.string_types):
+            if isinstance(extra_classes, str):
                 extra_classes = extra_classes.split(" ")
             body_classes.update(extra_classes)
 
@@ -329,12 +298,11 @@ class LayoutPolicy(BrowserView):
 
 @adapter(Interface)
 @implementer(IBodyClassAdapter)
-class DefaultBodyClasses(object):
+class DefaultBodyClasses:
     def __init__(self, context, request):
         self.context = context
         self.request = request
 
     def get_classes(self, template, view):
-        """Default body classes adapter.
-        """
+        """Default body classes adapter."""
         return []
