@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from .interfaces import IPortalState
 from Acquisition import aq_inner
 from plone.app.layout.navigation.root import getNavigationRoot
@@ -9,8 +8,9 @@ from plone.memoize.view import memoize_contextless
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone.interfaces import ISearchSchema
-from Products.CMFPlone.interfaces import ISiteSchema
+from Products.CMFPlone.interfaces import IPloneSiteRoot
+from plone.base.interfaces import ISearchSchema
+from plone.base.interfaces import ISiteSchema
 from Products.Five.browser import BrowserView
 from zope.component import getUtility
 from zope.component import providedBy
@@ -23,8 +23,7 @@ RIGHT_TO_LEFT = ["ar", "fa", "he", "ps"]
 
 @implementer(IPortalState)
 class PortalState(BrowserView):
-    """Information about the state of the portal
-    """
+    """Information about the state of the portal"""
 
     @memoize_contextless
     def portal(self):
@@ -53,6 +52,10 @@ class PortalState(BrowserView):
 
     @memoize
     def navigation_root_title(self):
+        navigation_root = self.navigation_root()
+        if IPloneSiteRoot.providedBy(navigation_root):
+            return self.portal_title()
+
         title = self.navigation_root().Title
         if callable(title):
             return title()
