@@ -1,7 +1,7 @@
 from DateTime import DateTime
 from gzip import GzipFile
 from io import BytesIO
-from plone.app.layout.navigation.interfaces import INavigationRoot
+from plone.base.interfaces import INavigationRoot
 from plone.app.layout.testing import INTEGRATION_TESTING
 from plone.app.testing import login
 from plone.app.testing import logout
