@@ -1,54 +1,53 @@
-# -*- coding: utf-8 -*-
 from AccessControl import getSecurityManager
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from collections import defaultdict
-from datetime import date
 from functools import total_ordering
+from html import escape
 from plone.app.layout.globals.interfaces import IViewView
 from plone.app.layout.navigation.root import getNavigationRoot
-from plone.app.layout.navigation.root import getNavigationRootObject
+from plone.base import PloneMessageFactory as _
+from plone.base.utils import safe_text
 from plone.i18n.interfaces import ILanguageSchema
 from plone.memoize.view import memoize
 from plone.protect.utils import addTokenToUrl
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone import PloneMessageFactory as _
-from Products.CMFPlone.interfaces import IPloneSiteRoot
-from Products.CMFPlone.interfaces import ISearchSchema
-from Products.CMFPlone.interfaces import ISiteSchema
-from Products.CMFPlone.interfaces.controlpanel import INavigationSchema
+from plone.base.interfaces import IPloneSiteRoot
+from plone.base.interfaces import ISearchSchema
+from plone.base.interfaces import ISiteSchema
+from plone.base.interfaces.controlpanel import INavigationSchema
 from Products.CMFPlone.utils import getSiteLogo
-from Products.CMFPlone.utils import safe_unicode
 from Products.Five.browser import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
-from six.moves.urllib.parse import unquote
+from urllib.parse import unquote
 from zope.component import getMultiAdapter
 from zope.component import getUtility
 from zope.component import queryMultiAdapter
-from zope.deprecation.deprecation import deprecate
 from zope.i18n import translate
 from zope.interface import alsoProvides
 from zope.interface import implementer
 from zope.viewlet.interfaces import IViewlet
 
 import json
+import zope.deferredimport
 
 
-try:
-    from html import escape
-except ImportError:
-    from cgi import escape
+zope.deferredimport.initialize()
+zope.deferredimport.deprecated(
+    "Import from plone.app.portlets.browser.viewlets instead",
+    ManagePortletsFallbackViewlet="plone.app.portlets.browser.viewlets:ManagePortletsFallbackViewlet",
+    FooterViewlet="plone.app.portlets.browser.viewlets:FooterViewlet",
+)
 
 
 @implementer(IViewlet)
 @total_ordering
 class ViewletBase(BrowserView):
-    """ Base class with common functions for link viewlets.
-    """
+    """Base class with common functions for link viewlets."""
 
     def __init__(self, context, request, view, manager=None):
-        super(ViewletBase, self).__init__(context, request)
+        super().__init__(context, request)
         self.__parent__ = view
         self.context = context
         self.request = request
@@ -58,16 +57,9 @@ class ViewletBase(BrowserView):
     def __hash__(self):
         return id(self) * 16
 
-    @property
-    @deprecate(
-        "Use site_url instead. " + "ViewletBase.portal_url will be removed in Plone 4"
-    )
-    def portal_url(self):
-        return self.site_url
-
     def update(self):
         self.portal_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_portal_state"
+            (self.context, self.request), name="plone_portal_state"
         )
         self.site_url = self.portal_state.portal_url()
         self.navigation_root_url = self.portal_state.navigation_root_url()
@@ -81,13 +73,11 @@ class ViewletBase(BrowserView):
         raise NotImplementedError("`index` method must be implemented by subclass.")
 
     def __lt__(self, other):
-        """ Sort by name
-        """
+        """Sort by name"""
         return self.__name__ < other.__name__
 
     def __eq__(self, other):
-        """ Check for equality
-        """
+        """Check for equality"""
         return id(self) == id(other)
 
 
@@ -95,7 +85,7 @@ class TitleViewlet(ViewletBase):
     index = ViewPageTemplateFile("title.pt")
 
     # seperator of page- and portal-title
-    sep = u" &mdash; "
+    sep = " &mdash; "
 
     @property
     @memoize
@@ -134,21 +124,21 @@ class TitleViewlet(ViewletBase):
             return self.site_title_setting
 
         context_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_context_state"
+            (self.context, self.request), name="plone_context_state"
         )
-        return escape(safe_unicode(context_state.object_title()))
+        return escape(safe_text(context_state.object_title()))
 
     def update(self):
         if IPloneSiteRoot.providedBy(self.context):
             self.site_title = self.site_title_setting
             return
         portal_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_portal_state"
+            (self.context, self.request), name="plone_portal_state"
         )
         if IPloneSiteRoot.providedBy(portal_state.navigation_root()):
             portal_title = self.site_title_setting
         else:
-            portal_title = escape(safe_unicode(portal_state.navigation_root_title()))
+            portal_title = escape(safe_text(portal_state.navigation_root_title()))
         if self.page_title == portal_title:
             self.site_title = portal_title
         else:
@@ -188,7 +178,7 @@ class SiteActionsViewlet(ViewletBase):
 
     def update(self):
         context_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_context_state"
+            (self.context, self.request), name="plone_context_state"
         )
         self.site_actions = context_state.actions("site_actions")
 
@@ -197,15 +187,16 @@ class SearchBoxViewlet(ViewletBase):
     index = ViewPageTemplateFile("searchbox.pt")
 
     def update(self):
-        super(SearchBoxViewlet, self).update()
+        super().update()
 
         context_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_context_state"
+            (self.context, self.request), name="plone_context_state"
         )
 
         registry = getUtility(IRegistry)
         search_settings = registry.forInterface(ISearchSchema, prefix="plone")
         self.livesearch = search_settings.enable_livesearch
+        self.show_images = search_settings.search_show_images
 
         folder = context_state.folder()
         self.folder_path = "/".join(folder.getPhysicalPath())
@@ -215,7 +206,7 @@ class LogoViewlet(ViewletBase):
     index = ViewPageTemplateFile("logo.pt")
 
     def update(self):
-        super(LogoViewlet, self).update()
+        super().update()
 
         # TODO: should this be changed to settings.site_title?
         self.navigation_root_title = self.portal_state.navigation_root_title()
@@ -230,57 +221,50 @@ class GlobalSectionsViewlet(ViewletBase):
     index = ViewPageTemplateFile("sections.pt")
 
     _opener_markup_template = (
-        u'<input id="navitem-{uid}" type="checkbox" class="opener" />'
-        u'<label for="navitem-{uid}" role="button" aria-label="{title}"></label>'  # noqa: E 501
+        '<input id="navitem-{uid}" type="checkbox" class="opener" />'
+        '<label for="navitem-{uid}" role="button" aria-label="{title}"></label>'  # noqa: E 501
     )
     _item_markup_template = (
-        u'<li class="{id}{has_sub_class}">'
-        u'<a href="{url}" class="state-{review_state}"{aria_haspopup}>{title}</a>{opener}'  # noqa: E 501
-        u"{sub}"
-        u"</li>"
+        '<li class="{id}{has_sub_class} nav-item">'
+        '<a href="{url}" class="state-{review_state} nav-link"{aria_haspopup}>{title}</a>{opener}'  # noqa: E 501
+        "{sub}"
+        "</li>"
     )
-    _subtree_markup_wrapper = u'<ul class="has_subtree dropdown">{out}</ul>'
+    _subtree_markup_wrapper = '<ul class="has_subtree dropdown">{out}</ul>'
+
+    def __init__(self, *args):
+        super().__init__(*args)
+        self.registry = getUtility(IRegistry)
 
     @property
     def settings(self):
-        registry = getUtility(IRegistry)
-        settings = registry.forInterface(INavigationSchema, prefix="plone")
-        return settings
+        return self.registry.forInterface(INavigationSchema, prefix="plone")
 
     @property
     def language_settings(self):
-        registry = getUtility(IRegistry)
-        settings = registry.forInterface(ILanguageSchema, prefix="plone")
-        return settings
+        return self.registry.forInterface(ILanguageSchema, prefix="plone")
 
     @property
     def navtree_path(self):
         return getNavigationRoot(self.context)
 
-    @property
-    @deprecate("This property will be removed in Plone 6")
-    def navtree_depth(self):
-        return self.settings.navigation_depth
-
     @property
     def current_language(self):
+        language_settings = self.registry.forInterface(ILanguageSchema, prefix="plone")
         return (
             self.request.get("LANGUAGE", None)
             or (self.context and aq_inner(self.context).Language())
-            or self.language_settings.default_language
+            or language_settings.default_language
         )
 
     @property
     def types_using_view(self):
-        registry = getUtility(IRegistry)
-        types_using_view = registry.get("plone.types_use_view_action_in_listings", [])
-        return types_using_view
+        return self.registry.get("plone.types_use_view_action_in_listings", [])
 
     @property
     @memoize
     def navtree(self):
         ret = defaultdict(list)
-        settings = self.settings
         navtree_path = self.navtree_path
         portal_tabs = self.portal_tabs
         for tab in portal_tabs:
@@ -302,12 +286,13 @@ class GlobalSectionsViewlet(ViewletBase):
                     entry["title"], domain="plone", context=self.request
                 )
 
-            entry["title"] = escape(safe_unicode(entry["title"]))
+            entry["title"] = escape(safe_text(entry["title"]))
             if "name" in entry and entry["name"]:
-                entry["name"] = escape(safe_unicode(entry["name"]))
+                entry["name"] = escape(safe_text(entry["name"]))
             self.customize_tab(entry, tab)
             ret[navtree_path].append(entry)
 
+        settings = self.settings
         if not settings.generate_tabs:
             return ret
 
@@ -339,7 +324,7 @@ class GlobalSectionsViewlet(ViewletBase):
         portal_catalog = getToolByName(self.context, "portal_catalog")
         brains = portal_catalog.searchResults(**query)
 
-        types_using_view = self.types_using_view
+        types_using_view = set(self.types_using_view)
         for brain in brains:
             brain_path = brain.getPath()
             brain_parent_path = brain_path.rpartition("/")[0]
@@ -357,7 +342,7 @@ class GlobalSectionsViewlet(ViewletBase):
                 "path": brain_path,
                 "uid": brain.UID,
                 "url": url,
-                "title": escape(safe_unicode(brain.Title)),
+                "title": escape(safe_text(brain.Title)),
                 "review_state": brain.review_state,
             }
             self.customize_entry(entry, brain)
@@ -390,7 +375,12 @@ class GlobalSectionsViewlet(ViewletBase):
             )
         else:
             item.update(
-                {"sub": sub, "opener": "", "aria_haspopup": "", "has_sub_class": "",}
+                {
+                    "sub": sub,
+                    "opener": "",
+                    "aria_haspopup": "",
+                    "has_sub_class": "",
+                }
             )
         return self._item_markup_template.format(**item)
 
@@ -398,7 +388,7 @@ class GlobalSectionsViewlet(ViewletBase):
         """Non-template based recursive tree building.
         3-4 times faster than template based.
         """
-        out = u""
+        out = ""
         for item in self.navtree.get(path, []):
             out += self.render_item(item, path)
 
@@ -417,54 +407,6 @@ class GlobalSectionsViewlet(ViewletBase):
         )
         return portal_tabs_view.topLevelTabs()
 
-    @deprecate("This method will be removed in Plone 6")
-    def selectedTabs(self, default_tab="index_html", portal_tabs=()):
-        portal = getToolByName(self.context, "portal_url").getPortalObject()
-        plone_url = getNavigationRootObject(self.context, portal).absolute_url()
-        plone_url_len = len(plone_url)
-        request = self.request
-        valid_actions = []
-
-        url = request["URL"]
-        path = url[plone_url_len:]
-        path_list = path.split("/")
-        if len(path_list) <= 1:
-            return {"portal": default_tab}
-
-        for action in portal_tabs:
-            if not action["url"].startswith(plone_url):
-                # In this case the action url is an external link. Then, we
-                # avoid issues (bad portal_tab selection) continuing with next
-                # action.
-                continue
-            action_path = action["url"][plone_url_len:]
-            if not action_path.startswith("/"):
-                action_path = "/" + action_path
-            action_path_list = action_path.split("/")
-            if action_path_list[1] == path_list[1]:
-                # Make a list of the action ids, along with the path length
-                # for choosing the longest (most relevant) path.
-                valid_actions.append((len(action_path_list), action["id"]))
-
-        # Sort by path length, the longest matching path wins
-        valid_actions.sort()
-        if valid_actions:
-            return {"portal": valid_actions[-1][1]}
-
-        return {"portal": default_tab}
-
-    @property
-    @memoize
-    @deprecate("This method will be removed in Plone 6")
-    def selected_tabs(self):
-        return self.selectedTabs(portal_tabs=self.portal_tabs)
-
-    @property
-    @memoize
-    @deprecate("This method will be removed in Plone 6")
-    def selected_portal_tab(self):
-        return self.selected_tabs["portal"]
-
 
 class PersonalBarViewlet(ViewletBase):
 
@@ -472,11 +414,11 @@ class PersonalBarViewlet(ViewletBase):
     user_name = ""
 
     def update(self):
-        super(PersonalBarViewlet, self).update()
+        super().update()
         context = aq_inner(self.context)
 
         context_state = getMultiAdapter(
-            (context, self.request), name=u"plone_context_state"
+            (context, self.request), name="plone_context_state"
         )
 
         user_actions = context_state.actions("user")
@@ -487,13 +429,14 @@ class PersonalBarViewlet(ViewletBase):
                 "href": action["url"],
                 "id": "personaltools-{}".format(action["id"]),
                 "target": action.get("link_target", None),
+                "icon": action.get("icon", None),
             }
             modal = action.get("modal")
             if modal:
                 info["class"] = "pat-plone-modal"
                 if '"title":' in modal:
                     modal = json.loads(modal)
-                    modal['title'] = translate(_(modal['title']), context=self.request)
+                    modal["title"] = translate(_(modal["title"]), context=self.request)
                     modal = json.dumps(modal)
 
                 info["data-pat-plone-modal"] = modal
@@ -505,7 +448,7 @@ class PersonalBarViewlet(ViewletBase):
             member = self.portal_state.member()
             userid = member.getId()
 
-            self.homelink_url = "%s/useractions" % self.navigation_root_url
+            self.homelink_url = f"{self.navigation_root_url}/useractions"
 
             membership = getToolByName(context, "portal_membership")
             member_info = membership.getMemberInfo(userid)
@@ -533,7 +476,7 @@ class ContentViewsViewlet(ViewletBase):
         # from plone.app.contentmenu. This behaves differently depending on
         # whether the view is marked with IViewView. If our parent view
         # provides that marker, we should do it here as well.
-        super(ContentViewsViewlet, self).update()
+        super().update()
         if IViewView.providedBy(self.__parent__):
             alsoProvides(self, IViewView)
 
@@ -546,7 +489,7 @@ class ContentViewsViewlet(ViewletBase):
         context_fti = context.getTypeInfo()
 
         context_state = getMultiAdapter(
-            (context, self.request), name=u"plone_context_state"
+            (context, self.request), name="plone_context_state"
         )
         actions = context_state.actions
 
@@ -579,7 +522,7 @@ class ContentViewsViewlet(ViewletBase):
             if starts("http") or starts("javascript"):
                 item["url"] = action_url
             else:
-                item["url"] = "%s/%s" % (context_url, action_url)
+                item["url"] = f"{context_url}/{action_url}"
             item["url"] = addTokenToUrl(item["url"], self.request)
 
             action_method = item["url"].split("/")[-1].split("?")[0]
@@ -645,40 +588,11 @@ class ContentViewsViewlet(ViewletBase):
         return icon.tag(title="Locked")
 
 
-class ManagePortletsFallbackViewlet(ViewletBase):
-    """Manage portlets fallback link that sits below content"""
-
-    index = ViewPageTemplateFile("manage_portlets_fallback.pt")
-
-    def update(self):
-        plonelayout = getMultiAdapter(
-            (self.context, self.request), name=u"plone_layout"
-        )
-        context_state = getMultiAdapter(
-            (self.context, self.request), name=u"plone_context_state"
-        )
-
-        self.portlet_assignable = context_state.portlet_assignable()
-        self.sl = plonelayout.have_portlets("plone.leftcolumn", self.context)
-        self.sr = plonelayout.have_portlets("plone.rightcolumn", self.context)
-        self.object_url = context_state.object_url()
-
-    def available(self):
-        secman = getSecurityManager()
-        has_manage_portlets_permission = secman.checkPermission(
-            "Portlets: Manage portlets", self.context
-        )
-        if not has_manage_portlets_permission:
-            return False
-        elif not self.sl and not self.sr and self.portlet_assignable:
-            return True
-
-
 class PathBarViewlet(ViewletBase):
     index = ViewPageTemplateFile("path_bar.pt")
 
     def update(self):
-        super(PathBarViewlet, self).update()
+        super().update()
 
         self.is_rtl = self.portal_state.is_rtl()
 
@@ -690,39 +604,3 @@ class PathBarViewlet(ViewletBase):
 
 class TinyLogoViewlet(ViewletBase):
     index = ViewPageTemplateFile("tiny_logo.pt")
-
-
-class FooterViewlet(ViewletBase):
-    index = ViewPageTemplateFile("footer.pt")
-
-    def update(self):
-        super(FooterViewlet, self).update()
-        self.year = date.today().year
-
-    def render_footer_portlets(self):
-        """
-        You might ask, why is this necessary. Well, let me tell you a story...
-
-        plone.app.portlets, in order to provide @@manage-portlets on a context,
-        overrides the IPortletRenderer for the IManageContextualPortletsView
-        view.
-        See plone.portlets and plone.app.portlets
-
-        Seems fine right? Well, most of the time it is. Except, here.
-        Previously, we were just using the syntax like
-        `provider:plone.footerportlets` to render the footer portlets.
-        Since this tal expression was inside a viewlet,
-        the view is no longer IManageContextualPortletsView when
-        visiting @@manage-portlets. Instead, it was IViewlet.
-        See zope.contentprovider
-
-        In to fix this short coming, we render the portlet column by
-        manually doing the multi adapter lookup and then manually
-        doing the rendering for the content provider.
-        See zope.contentprovider
-        """
-        portlet_manager = getMultiAdapter(
-            (self.context, self.request, self.__parent__), name="plone.footerportlets"
-        )
-        portlet_manager.update()
-        return portlet_manager.render()
