@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
-from plone.app.layout.navigation.interfaces import INavigationRoot
+from plone.base.interfaces import INavigationRoot
 from plone.app.layout.viewlets.common import ContentViewsViewlet
 from plone.app.layout.viewlets.common import GlobalSectionsViewlet
 from plone.app.layout.viewlets.common import LogoViewlet
 from plone.app.layout.viewlets.common import TitleViewlet
 from plone.app.layout.viewlets.common import ViewletBase
-from plone.app.layout.viewlets.tests.base import ViewletsTestCase
 from plone.app.layout.viewlets.tests.base import ViewletsFunctionalTestCase
+from plone.app.layout.viewlets.tests.base import ViewletsTestCase
 from plone.app.testing import setRoles
 from plone.app.testing import SITE_OWNER_NAME
 from plone.app.testing import SITE_OWNER_PASSWORD
@@ -14,8 +13,8 @@ from plone.app.testing import TEST_USER_ID
 from plone.protect import authenticator as auth
 from plone.registry.interfaces import IRegistry
 from plone.testing.zope import Browser
-from Products.CMFPlone.interfaces import INonStructuralFolder
-from Products.CMFPlone.interfaces import ISiteSchema
+from plone.base.interfaces import INonStructuralFolder
+from plone.base.interfaces import ISiteSchema
 from zope.component import getUtility
 from zope.component.hooks import setSite
 from zope.interface import alsoProvides
@@ -38,8 +37,7 @@ HACKED = '<script>alert("hacked")</script>'
 
 
 class TestViewletBase(ViewletsTestCase):
-    """Test the base class for the viewlets.
-    """
+    """Test the base class for the viewlets."""
 
     def test_update(self):
         request = self.layer["request"]
@@ -54,13 +52,12 @@ class TestViewletBase(ViewletsTestCase):
 
 
 class TestContentViewsViewlet(ViewletsTestCase):
-    """Test the content views viewlet.
-    """
+    """Test the content views viewlet."""
 
     def setUp(self):
-        super(TestContentViewsViewlet, self).setUp()
+        super().setUp()
         self.folder.invokeFactory("Document", "test", title="Test default page")
-        self.folder.title = u"Folder"
+        self.folder.title = "Folder"
 
     def _invalidateRequestMemoizations(self):
         try:
@@ -91,7 +88,7 @@ class TestContentViewsViewlet(ViewletsTestCase):
     def test_set1(self):
         self._invalidateRequestMemoizations()
         setRoles(self.portal, TEST_USER_ID, ["Manager", "Member"])
-        self.app.REQUEST["ACTUAL_URL"] = "%s/edit?_authenticator=%s" % (
+        self.app.REQUEST["ACTUAL_URL"] = "{}/edit?_authenticator={}".format(
             self.folder.test.absolute_url(),
             auth.createToken(),
         )
@@ -104,13 +101,12 @@ class TestContentViewsViewlet(ViewletsTestCase):
 
 
 class TestTitleViewsViewlet(ViewletsTestCase):
-    """Test the title viewlet.
-    """
+    """Test the title viewlet."""
 
     def setUp(self):
-        super(TestTitleViewsViewlet, self).setUp()
+        super().setUp()
         self.folder.invokeFactory("Document", "test", title="Test default page")
-        self.folder.title = u"Folder"
+        self.folder.title = "Folder"
 
     def _invalidateRequestMemoizations(self):
         try:
@@ -119,8 +115,7 @@ class TestTitleViewsViewlet(ViewletsTestCase):
             pass
 
     def test_title_viewlet_on_portal(self):
-        """Title viewlet renders navigation root title
-        """
+        """Title viewlet renders navigation root title"""
         self._invalidateRequestMemoizations()
         setRoles(self.portal, TEST_USER_ID, ["Manager", "Member"])
         self.app.REQUEST["ACTUAL_URL"] = self.portal.absolute_url()
@@ -129,14 +124,13 @@ class TestTitleViewsViewlet(ViewletsTestCase):
         self.assertEqual(viewlet.site_title, "Plone site")
         registry = getUtility(IRegistry)
         site_settings = registry.forInterface(ISiteSchema, prefix="plone", check=False)
-        site_settings.site_title = u"Süper Site"
+        site_settings.site_title = "Süper Site"
         self._invalidateRequestMemoizations()
         viewlet.update()
-        self.assertEqual(viewlet.site_title, u"S\xfcper Site")
+        self.assertEqual(viewlet.site_title, "S\xfcper Site")
 
     def test_title_viewlet_on_content(self):
-        """Title viewlet renders navigation root title
-        """
+        """Title viewlet renders navigation root title"""
         self._invalidateRequestMemoizations()
         setRoles(self.portal, TEST_USER_ID, ["Manager", "Member"])
         self.app.REQUEST["ACTUAL_URL"] = self.folder.test.absolute_url()
@@ -145,30 +139,27 @@ class TestTitleViewsViewlet(ViewletsTestCase):
         self.assertEqual(viewlet.site_title, "Test default page &mdash; Plone site")
         registry = getUtility(IRegistry)
         site_settings = registry.forInterface(ISiteSchema, prefix="plone", check=False)
-        site_settings.site_title = u"Süper Site"
+        site_settings.site_title = "Süper Site"
         self._invalidateRequestMemoizations()
         viewlet.update()
-        self.assertEqual(viewlet.site_title, u"Test default page &mdash; S\xfcper Site")
+        self.assertEqual(viewlet.site_title, "Test default page &mdash; S\xfcper Site")
 
     def test_title_viewlet_with_navigation_root(self):
-        """Title viewlet renders navigation root title
-        """
+        """Title viewlet renders navigation root title"""
         self._invalidateRequestMemoizations()
         setRoles(self.portal, TEST_USER_ID, ["Manager", "Member"])
         self.app.REQUEST["ACTUAL_URL"] = self.folder.test.absolute_url()
         directlyProvides(self.folder, INavigationRoot)
         viewlet = TitleViewlet(self.folder.test, self.app.REQUEST, None)
         viewlet.update()
-        self.assertEqual(viewlet.site_title, u"Test default page &mdash; Folder")
+        self.assertEqual(viewlet.site_title, "Test default page &mdash; Folder")
 
 
 class TestLogoViewlet(ViewletsTestCase):
-    """Test the site logo viewlet.
-    """
+    """Test the site logo viewlet."""
 
     def _set_site(self, context):
-        """Set context as a site.
-        """
+        """Set context as a site."""
         # Set the portal's getSiteManager method on context.
         # This is a hackish way to make setSite work without creating a site
         # with five.localsitemanager.
@@ -182,9 +173,7 @@ class TestLogoViewlet(ViewletsTestCase):
         """
         viewlet = LogoViewlet(self.folder, self.app.REQUEST, None)
         viewlet.update()
-        self.assertEqual(
-            viewlet.img_src, "{0}/logo.png".format(self.portal.absolute_url())
-        )
+        self.assertEqual(viewlet.img_src, f"{self.portal.absolute_url()}/++resource++plone-logo.svg")
 
     def test_logo_viewlet_portal_root_registry(self):
         """When a logo is set, and viewlet is opened on a non-navigation root,
@@ -198,7 +187,7 @@ class TestLogoViewlet(ViewletsTestCase):
         viewlet.update()
         self.assertTrue(
             viewlet.img_src,
-            "{0}/@@site-logo/pixel.png".format(self.portal.absolute_url()),
+            f"{self.portal.absolute_url()}/@@site-logo/pixel.png",
         )
 
     def test_logo_viewlet_navigation_root_default(self):
@@ -208,9 +197,7 @@ class TestLogoViewlet(ViewletsTestCase):
         self._set_site(self.folder)
         viewlet = LogoViewlet(self.folder, self.app.REQUEST, None)
         viewlet.update()
-        self.assertEqual(
-            viewlet.img_src, "{0}/logo.png".format(self.folder.absolute_url())
-        )
+        self.assertEqual(viewlet.img_src, f"{self.folder.absolute_url()}/++resource++plone-logo.svg")
 
     def test_viewlet_navigation_root_registry(self):
         """When a logo is set, and viewlet is opened on a navigation root,
@@ -226,13 +213,12 @@ class TestLogoViewlet(ViewletsTestCase):
         viewlet.update()
         self.assertTrue(
             viewlet.img_src,
-            "{0}/@@site-logo/pixel.png".format(self.folder.absolute_url()),
+            f"{self.folder.absolute_url()}/@@site-logo/pixel.png",
         )
 
 
 class TestGlobalSectionsViewlet(ViewletsTestCase):
-    """Test the global sections views viewlet.
-    """
+    """Test the global sections views viewlet."""
 
     def setUp(self):
         self.portal = self.layer["portal"]
@@ -250,34 +236,34 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
         return gsv.navtree
 
     def test_globalnav_respects_types_use_view_action_in_listings(self):
-        """ Test selected tabs with a INavigationroot folder involved
-        """
+        """Test selected tabs with a INavigationroot folder involved"""
         setRoles(self.portal, TEST_USER_ID, ["Manager"])
-        self.portal.invokeFactory("Image", "image", title=u"Söme Image")
-        self.portal.invokeFactory("File", "file", title=u"Some File")
-        self.portal.invokeFactory("Document", "doc", title=u"Some Döcument")
+        self.portal.invokeFactory("Image", "image", title="Söme Image")
+        self.portal.invokeFactory("File", "file", title="Some File")
+        self.portal.invokeFactory("Document", "doc", title="Some Döcument")
+        self.portal.invokeFactory("Collection", "collection", title="Some Collection")
         request = self.layer["request"]
         gsv = GlobalSectionsViewlet(self.portal, request, None)
         gsv.update()
         html = gsv.render()
-        self.assertIn('href="http://nohost/plone/image/view"', html)
-        self.assertIn('href="http://nohost/plone/file/view"', html)
+        self.assertIn('href="http://nohost/plone/collection"', html)
+        self.assertNotIn('href="http://nohost/plone/image/view"', html)
+        self.assertNotIn('href="http://nohost/plone/file/view"', html)
         self.assertIn('href="http://nohost/plone/doc"', html)
 
     def test_globalnav_navigation_depth(self):
-        """ Test selected tabs with a INavigationroot folder involved
-        """
+        """Test selected tabs with a INavigationroot folder involved"""
         setRoles(self.portal, TEST_USER_ID, ["Manager"])
         registry = getUtility(IRegistry)
         registry["plone.navigation_depth"] = 3
-        self.portal.invokeFactory("Folder", "folder", title=u"Földer")
-        self.portal.invokeFactory("Folder", "folder2", title=u"Folder 2")
-        self.portal.invokeFactory("Folder", "folder3", title=u"Folder 3")
+        self.portal.invokeFactory("Folder", "folder", title="Földer")
+        self.portal.invokeFactory("Folder", "folder2", title="Folder 2")
+        self.portal.invokeFactory("Folder", "folder3", title="Folder 3")
         folder = self.portal.folder
-        folder.invokeFactory("Folder", "subfolder", title=u"Subfolder")
-        folder.invokeFactory("Folder", "subfolder2", title=u"Sübfolder 2")
+        folder.invokeFactory("Folder", "subfolder", title="Subfolder")
+        folder.invokeFactory("Folder", "subfolder2", title="Sübfolder 2")
         subfolder = folder.subfolder
-        subfolder.invokeFactory("Folder", "subsubfolder", title=u"Sub2folder")
+        subfolder.invokeFactory("Folder", "subsubfolder", title="Sub2folder")
 
         request = self.layer["request"]
         navtree = self._get_navtree()
@@ -287,14 +273,15 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
         )
         self.assertListEqual(
             [x["title"] for x in navtree["/plone"]],
-            [u"Home", u"Members", u"Földer", u"Folder 2", u"Folder 3"],
+            ["Home", "Members", "Földer", "Folder 2", "Folder 3"],
         )
         self.assertListEqual(
             [x["title"] for x in navtree["/plone/folder"]],
-            [u"Subfolder", u"Sübfolder 2"],
+            ["Subfolder", "Sübfolder 2"],
         )
         self.assertListEqual(
-            [x["title"] for x in navtree["/plone/folder/subfolder"]], [u"Sub2folder"],
+            [x["title"] for x in navtree["/plone/folder/subfolder"]],
+            ["Sub2folder"],
         )
 
         gsv = GlobalSectionsViewlet(self.portal, request, None)
@@ -315,13 +302,16 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
         navtree = self._get_navtree()
         self.assertListEqual(sorted(navtree), ["/plone"])
         self.assertListEqual(
-            [item["path"] for item in navtree["/plone"]], ["/plone/index_html"],
+            [item["path"] for item in navtree["/plone"]],
+            ["/plone/index_html"],
         )
 
     def test_generate_tabs_non_folderish(self):
         self.registry["plone.nonfolderish_tabs"] = False
         self.portal.invokeFactory(
-            "Document", "test-doc", title=u"A simple document (àèìòù)",
+            "Document",
+            "test-doc",
+            title="A simple document (àèìòù)",
         )
         navtree = self._get_navtree()
         self.assertListEqual(sorted(navtree), ["/plone", "/plone/Members"])
@@ -332,10 +322,14 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
 
     def test_generate_tabs_sorted(self):
         self.portal.invokeFactory(
-            "Document", "test-doc-2", title=u"Document 2",
+            "Document",
+            "test-doc-2",
+            title="Document 2",
         )
         self.portal.invokeFactory(
-            "Document", "test-doc-1", title=u"Document 1",
+            "Document",
+            "test-doc-1",
+            title="Document 1",
         )
         navtree = self._get_navtree()
         # default sorting by position in parent
@@ -351,7 +345,7 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
         )
 
         # check we can sort by title
-        self.registry["plone.sort_tabs_on"] = u"sortable_title"
+        self.registry["plone.sort_tabs_on"] = "sortable_title"
         navtree = self._get_navtree()
         self.assertListEqual(sorted(navtree), ["/plone", "/plone/Members"])
         self.assertListEqual(
@@ -380,25 +374,31 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
 
     def test_generate_tabs_displayed_types(self):
         self.registry["plone.displayed_types"] = (
-            u"Image",
-            u"File",
-            u"Link",
-            u"News Item",
-            u"Document",
-            u"Event",
+            "Image",
+            "File",
+            "Link",
+            "News Item",
+            "Document",
+            "Event",
         )
         navtree = self._get_navtree()
         self.assertListEqual(
-            [item["path"] for item in navtree["/plone"]], ["/plone/index_html",],
+            [item["path"] for item in navtree["/plone"]],
+            [
+                "/plone/index_html",
+            ],
         )
 
     def test_generate_tabs_filter_on_state(self):
         self.registry["plone.filter_on_workflow"] = True
         navtree = self._get_navtree()
         self.assertListEqual(
-            [item["path"] for item in navtree["/plone"]], ["/plone/index_html",],
+            [item["path"] for item in navtree["/plone"]],
+            [
+                "/plone/index_html",
+            ],
         )
-        self.registry["plone.workflow_states_to_show"] = (u"private",)
+        self.registry["plone.workflow_states_to_show"] = ("private",)
         navtree = self._get_navtree()
         self.assertListEqual(sorted(navtree), ["/plone", "/plone/Members"])
         self.assertListEqual(
@@ -421,29 +421,38 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
 
     def test_generate_tabs_exclude_from_nav(self):
         self.portal.invokeFactory(
-            "Folder", "test-folder", title=u"Test folder",
+            "Folder",
+            "test-folder",
+            title="Test folder",
         )
         self.portal.invokeFactory(
             "Folder",
             "excluded-folder",
-            title=u"Excluded folder",
+            title="Excluded folder",
             exclude_from_nav=True,
         )
         self.portal["excluded-folder"].invokeFactory(
-            "Folder", "sub-folder", title=u"Sub folder",
+            "Folder",
+            "sub-folder",
+            title="Sub folder",
         )
 
         navtree = self._get_navtree()
         self.assertListEqual(
             [item["path"] for item in navtree["/plone"]],
-            ["/plone/index_html", "/plone/Members", "/plone/test-folder",],
+            [
+                "/plone/index_html",
+                "/plone/Members",
+                "/plone/test-folder",
+            ],
         )
 
         # Check also that we we have proper nesting
         self.registry["plone.navigation_depth"] = 2
         navtree = self._get_navtree()
         self.assertListEqual(
-            sorted(navtree), ["/plone", "/plone/Members", "/plone/excluded-folder"],
+            sorted(navtree),
+            ["/plone", "/plone/Members", "/plone/excluded-folder"],
         )
         self.assertListEqual(
             [item["path"] for item in navtree["/plone/excluded-folder"]],
@@ -464,7 +473,8 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
         self.registry["plone.navigation_depth"] = 2
         navtree = self._get_navtree()
         self.assertListEqual(
-            sorted(navtree), ["/plone", "/plone/Members", "/plone/excluded-folder"],
+            sorted(navtree),
+            ["/plone", "/plone/Members", "/plone/excluded-folder"],
         )
         self.assertListEqual(
             [item["path"] for item in navtree["/plone"]],
@@ -479,7 +489,8 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
         self.portal["excluded-folder"]["sub-folder"].reindexObject()
         navtree = self._get_navtree()
         self.assertListEqual(
-            sorted(navtree), ["/plone", "/plone/Members"],
+            sorted(navtree),
+            ["/plone", "/plone/Members"],
         )
         self.assertListEqual(
             [item["path"] for item in navtree["/plone"]],
@@ -606,7 +617,9 @@ class TestGlobalSectionsViewlet(ViewletsTestCase):
         """Test for https://github.com/plone/plone.app.layout/issues/280."""
 
         self.portal.invokeFactory(
-            "Document", "test-doc-1", title=u"Document 1 & 2",
+            "Document",
+            "test-doc-1",
+            title="Document 1 & 2",
         )
 
         request = self.layer["request"]
@@ -635,7 +648,7 @@ class TestTitleEscape(ViewletsFunctionalTestCase):
         browser.handleErrors = False
         browser.addHeader(
             "Authorization",
-            "Basic {0}:{1}".format(SITE_OWNER_NAME, SITE_OWNER_PASSWORD),
+            f"Basic {SITE_OWNER_NAME}:{SITE_OWNER_PASSWORD}",
         )
         return browser
 
@@ -653,7 +666,7 @@ class TestTitleEscape(ViewletsFunctionalTestCase):
             index = body.index(hacked)
             start = max(0, index - 50)
             end = min(index + len(hacked) + 50, len(body))
-            assert False, "Hacked script found in body: ... {0} ...".format(
+            assert False, "Hacked script found in body: ... {} ...".format(
                 body[start:end]
             )
 
